@@ -1,4 +1,4 @@
-;;; mime-play.el --- Playback processing module for mime-view.el
+;;; mime-play.el --- Playback processing module for mime-view.el  -*- lexical-binding: t -*-
 
 ;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003,
 ;;   2004, 2010 Free Software Foundation, Inc.
@@ -31,9 +31,7 @@
 (require 'alist)
 (require 'filename)
 
-(eval-when-compile
-  (unless (require 'bbdb nil t)
-    (defvar bbdb-buffer-name nil)))
+(defvar bbdb-buffer-name)
 
 (defcustom mime-save-directory "~/"
   "*Name of the directory where MIME entity will be saved in.
@@ -81,8 +79,7 @@ If MODE is specified, play as it.  Default MODE is \"play\"."
 	      (setq situation
 		    (cons (cons 'ignore-examples ignore-examples)
 			  situation)))
-	  (mime-play-entity entity situation)
-	  ))))
+	  (mime-play-entity entity situation)))))
 
 ;;;###autoload
 (defun mime-play-entity (entity &optional situation ignored-method)
@@ -102,27 +99,22 @@ specified, play as it.  Default MODE is \"play\"."
     (cond ((cdr ret)
 	   (setq ret (mime-select-menu-alist
 		      "Methods"
-		      (mapcar (function
-			       (lambda (situation)
-				 (cons
-				  (format "%s"
-					  (cdr (assq 'method situation)))
-				  situation)))
+		      (mapcar (lambda (situation)
+				(cons
+				 (format "%s"
+					 (cdr (assq 'method situation)))
+				 situation))
 			      ret)))
 	   (setq ret (mime-sort-situation ret))
-	   (add-to-list 'mime-acting-situation-example-list (cons ret 0))
-	   )
+	   (add-to-list 'mime-acting-situation-example-list (cons ret 0)))
 	  (t
-	   (setq ret (car ret))
-	   ))
+	   (setq ret (car ret))))
     (setq method (cdr (assq 'method ret)))
     (cond ((and (symbolp method)
 		(fboundp method))
-	   (funcall method entity ret)
-	   )
+	   (funcall method entity ret))
 	  ((stringp method)
-	   (mime-activate-mailcap-method entity ret)
-	   )
+	   (mime-activate-mailcap-method entity ret))
           ;; ((and (listp method)(stringp (car method)))
           ;;  (mime-activate-external-method entity ret)
           ;;  )
@@ -132,9 +124,7 @@ specified, play as it.  Default MODE is \"play\"."
 				   (cdr (assq 'type situation))
 				   (cdr (assq 'subtype situation))))
 	   (if (y-or-n-p "Do you want to save current entity to disk?")
-	       (mime-save-content entity situation))
-	   ))
-    ))
+	       (mime-save-content entity situation))))))
 
 
 ;;; @ external decoder
@@ -187,10 +177,7 @@ specified, play as it.  Default MODE is \"play\"."
   "*If non-nil, mime-echo window is shared with BBDB window.")
 
 (defvar mime-echo-window-height
-  (function
-   (lambda ()
-     (/ (window-height) 5)
-     ))
+  (lambda () (/ (window-height) 5))
   "*Size of mime-echo window.
 It allows function or integer.  If it is function,
 `mime-show-echo-buffer' calls it to get height of mime-echo window.
@@ -213,19 +200,14 @@ window.")
 		   (- (window-height)
 		      (if (functionp mime-echo-window-height)
 			  (funcall mime-echo-window-height)
-			mime-echo-window-height)
-		      )))
-	)
-      (set-window-buffer win mime-echo-buffer-name)
-      )
+			mime-echo-window-height)))))
+      (set-window-buffer win mime-echo-buffer-name))
     (select-window win)
     (goto-char (point-max))
     (if forms
 	(let ((buffer-read-only nil))
-	  (insert (apply (function format) forms))
-	  ))
-    (select-window the-win)
-    ))
+	  (insert (apply (function format) forms))))
+    (select-window the-win)))
 
 
 ;;; @ file name
@@ -250,17 +232,15 @@ window.")
 	       (if (and subj
 			(or (string-match mime-view-file-name-regexp-1 subj)
 			    (string-match mime-view-file-name-regexp-2 subj)))
-		   (substring subj (match-beginning 0)(match-end 0))
-		 )))))
+		   (substring subj (match-beginning 0)(match-end 0)))))))
     (if filename
-	(replace-as-filename filename)
-      )))
+	(replace-as-filename filename))))
 
 
 ;;; @ file extraction
 ;;;
 
-(defun mime-save-content (entity situation)
+(defun mime-save-content (entity _situation)
   (let ((name (or (mime-entity-safe-filename entity)
 		  (format "%s" (mime-entity-media-type entity))))
 	(dir (if (eq t mime-save-directory)
@@ -293,8 +273,7 @@ window.")
     ("^II\\*\000"			image tiff)
     ("^MM\000\\*"			image tiff)
     ("^MThd"				audio midi)
-    ("^\000\000\001\263"		video mpeg)
-    )
+    ("^\000\000\001\263"		video mpeg))
   "*Alist of regexp about magic-number vs. corresponding media-types.
 Each element looks like (REGEXP TYPE SUBTYPE).
 REGEXP is a regular expression to match against the beginning of the
@@ -310,8 +289,7 @@ SUBTYPE is symbol to indicate subtype of media-type.")
 		    (if cell
 			(if (string-match (car cell) mdata)
 			    (setq type (nth 1 cell)
-				  subtype (nth 2 cell))
-			  )
+				  subtype (nth 2 cell)))
 		      t)))
 	(setq rest (cdr rest))))
     (setq situation (del-alist 'method (copy-alist situation)))
@@ -327,6 +305,8 @@ SUBTYPE is symbol to indicate subtype of media-type.")
 ;;; @ mail/news message
 ;;;
 
+(defvar mime-view-temp-message-buffer nil) ; buffer local variable
+
 (defun mime-preview-quitting-method-for-mime-show-message-mode ()
   "Quitting method for mime-view.
 It is registered to variable `mime-preview-quitting-method-alist'."
@@ -338,7 +318,7 @@ It is registered to variable `mime-preview-quitting-method-alist'."
     (set-window-configuration win-conf)
     (pop-to-buffer mother)))
 
-(defun mime-view-message/rfc822 (entity situation)
+(defun mime-view-message/rfc822 (entity _situation)
   (let* ((new-name
 	  (format "%s-%s" (buffer-name) (mime-entity-number entity)))
 	 (mother (current-buffer))
@@ -352,8 +332,7 @@ It is registered to variable `mime-preview-quitting-method-alist'."
 	(let ((m-win (get-buffer-window mother)))
 	  (if m-win
 	      (set-window-buffer m-win preview-buffer)
-	    (switch-to-buffer preview-buffer)
-	    )))))
+	    (switch-to-buffer preview-buffer))))))
 
 
 ;;; @ message/partial
@@ -377,8 +356,6 @@ occurs."
 	    (make-directory dir))
 	(set-default-file-modes orig-modes)))))
 
-(defvar mime-view-temp-message-buffer nil) ; buffer local variable
-
 (defun mime-store-message/partial-piece (entity cal)
   (let ((root-dir
 	 (expand-file-name
@@ -435,81 +412,70 @@ occurs."
 			  (erase-buffer)
 			  (insert total)
 			  (write-region (point-min)(point-max) total-file)
-			  (kill-buffer (current-buffer))
-			  ))
-		    (string-to-number total)
-		    )
+			  (kill-buffer (current-buffer))))
+		    (string-to-number total))
 		(and (file-exists-p total-file)
 		     (with-current-buffer (find-file-noselect total-file)
 		       (prog1
 			   (and (re-search-forward "[0-9]+" nil t)
 				(string-to-number
 				 (buffer-substring (match-beginning 0)
-						   (match-end 0)))
-				)
-			 (kill-buffer (current-buffer))
-			 )))
-		)))
+						   (match-end 0))))
+			 (kill-buffer (current-buffer))))))))
       (if (and total (> total 0)
 	       (>= (length (directory-files root-dir nil "^[0-9]+$" t))
 		   total))
 	  (catch 'tag
 	    (with-current-buffer (get-buffer-create mime-temp-buffer-name)
-	      (let ((full-buf (current-buffer)))
-		(erase-buffer)
-		(let ((i 1))
-		  (while (<= i total)
-		    (setq file (concat root-dir "/" (int-to-string i)))
-		    (or (file-exists-p file)
-			(throw 'tag nil)
-			)
-		    (binary-insert-encoded-file file)
-		    (goto-char (point-max))
-		    (setq i (1+ i))))
-		(binary-write-decoded-region
-		 (point-min)(point-max)
-		 (expand-file-name "FULL" root-dir))
-		(let ((i 1))
-		  (while (<= i total)
-		    (let ((file (format "%s/%d" root-dir i)))
-		      (and (file-exists-p file)
-			   (delete-file file)))
-		    (setq i (1+ i))))
-		(let ((file (expand-file-name "CT" root-dir)))
-		  (and (file-exists-p file)
-		       (delete-file file)))
-		(let ((buf (current-buffer))
-		      (pwin (or (get-buffer-window mother)
-				(get-largest-window)))
-		      (pbuf (mime-display-message
-			     (mime-open-entity 'buffer (current-buffer))
-			     nil mother nil 'mime-show-message-mode)))
-		  (with-current-buffer pbuf
-		    (make-local-variable 'mime-view-temp-message-buffer)
-		    (setq mime-view-temp-message-buffer buf))
-		  (set-window-buffer pwin pbuf)
-		  (select-window pwin)
-		  )))))
-      )))
+	      (erase-buffer)
+	      (let ((i 1))
+		(while (<= i total)
+		  (setq file (concat root-dir "/" (int-to-string i)))
+		  (or (file-exists-p file)
+		      (throw 'tag nil))
+		  (binary-insert-encoded-file file)
+		  (goto-char (point-max))
+		  (setq i (1+ i))))
+	      (binary-write-decoded-region
+	       (point-min)(point-max)
+	       (expand-file-name "FULL" root-dir))
+	      (let ((i 1))
+		(while (<= i total)
+		  (let ((file (format "%s/%d" root-dir i)))
+		    (and (file-exists-p file)
+			 (delete-file file)))
+		  (setq i (1+ i))))
+	      (let ((file (expand-file-name "CT" root-dir)))
+		(and (file-exists-p file)
+		     (delete-file file)))
+	      (let ((buf (current-buffer))
+		    (pwin (or (get-buffer-window mother)
+			      (get-largest-window)))
+		    (pbuf (mime-display-message
+			   (mime-open-entity 'buffer (current-buffer))
+			   nil mother nil 'mime-show-message-mode)))
+		(with-current-buffer pbuf
+		  (make-local-variable 'mime-view-temp-message-buffer)
+		  (setq mime-view-temp-message-buffer buf))
+		(set-window-buffer pwin pbuf)
+		(select-window pwin))))))))
 
 
 ;;; @ message/external-body
 ;;;
 
 (defvar mime-raw-dired-function
-  (if (and (>= emacs-major-version 19) window-system)
+  (if window-system
       (function dired-other-frame)
-    (function mime-raw-dired-function-for-one-frame)
-    ))
+    (function mime-raw-dired-function-for-one-frame)))
 
 (defun mime-raw-dired-function-for-one-frame (dir)
   (let ((win (or (get-buffer-window mime-preview-buffer)
 		 (get-largest-window))))
     (select-window win)
-    (dired dir)
-    ))
+    (dired dir)))
 
-(defun mime-view-message/external-anon-ftp (entity cal)
+(defun mime-view-message/external-anon-ftp (_entity cal)
   (let* ((site (cdr (assoc "site" cal)))
 	 (directory (cdr (assoc "directory" cal)))
 	 (name (cdr (assoc "name" cal)))
@@ -517,12 +483,11 @@ occurs."
     (message "%s" (concat "Accessing " (expand-file-name name pathname) "..."))
     (funcall mime-raw-dired-function pathname)
     (goto-char (point-min))
-    (search-forward name)
-    ))
+    (search-forward name)))
 
 (defvar mime-raw-browse-url-function mime-browse-url-function)
 
-(defun mime-view-message/external-url (entity cal)
+(defun mime-view-message/external-url (_entity cal)
   (let ((url (cdr (assoc "url" cal))))
     (message "%s" (concat "Accessing " url "..."))
     (funcall mime-raw-browse-url-function url)))
@@ -531,7 +496,7 @@ occurs."
 ;;; @ rot13-47
 ;;;
 
-(defun mime-view-caesar (entity situation)
+(defun mime-view-caesar (entity _situation)
   "Internal method for mime-view to display ROT13-47-48 message."
   (let ((buf (get-buffer-create
 	      (format "%s-%s" (buffer-name) (mime-entity-number entity)))))
@@ -540,15 +505,12 @@ occurs."
       (erase-buffer)
       (mime-insert-text-content entity)
       (mule-caesar-region (point-min) (point-max))
-      (set-buffer-modified-p nil)
-      )
+      (set-buffer-modified-p nil))
     (let ((win (get-buffer-window (current-buffer))))
       (or (eq (selected-window) win)
-	  (select-window (or win (get-largest-window)))
-	  ))
+	  (select-window (or win (get-largest-window)))))
     (view-buffer buf)
-    (goto-char (point-min))
-    ))
+    (goto-char (point-min))))
 
 
 ;;; @ end
